class UsersController < ApplicationController

  include Pundit

  before_action :authenticate_user!, only: [:follow, :unfollow]
  before_action :check_current_user_page, only: :show
  before_action :set_user, only: [:show]
  before_action :set_institutions, only: :me
  before_action :set_empty_collection, only: [:show, :me]
  before_action :set_followable, only: [:follow, :unfollow]

  def show
    @objects = @user.learning_objects
    @institutions = @user.institutions
    @groups = [CollectionsGroup.new(title: 'Coleções Adicionadas', collections: [ CollectionPolicy::Scope.new(current_user, @user.id, @user.collections).resolve.includes(:owner)])]

    if @user == current_user
      @publishers = @user.institutions
      @bookmarks = (@user.bookmarks.nil? || @user.bookmarks.first.nil?) ? [] : [@user.bookmarks.first]
      @groups.unshift(CollectionsGroup.new(title: 'Coleções Automáticas', collections: @bookmarks))
    end
  end

  def list
    @users = User.all
  end

  def follow
    Follow.create(user: current_user, followable: @followable) unless @followable.nil?

    redirect_to user_path(@followable)
  end

  def unfollow
    Follow.where(user: current_user, followable: @followable).destroy_all unless @followable.nil?

    redirect_to user_path(@followable)
  end

  def verify_email
    exists = User.find_by_email(params[:email])
    render json: { valid: exists.nil? && !params[:email].match(Devise.email_regexp).nil? }
  end

  private

  def set_empty_collection
    @new_collection = Collection.new
  end

  def set_institutions
    @institutions = current_user.institutions
  end

  def set_user
    @user = User.find params[:id]
  end

  def set_followable
    @followable = params[:followable_type].constantize.find(params[:followable_id]) if %w(Collection User).include? params[:followable_type]
  end

  def check_current_user_page
    if user_signed_in?
      if current_user.id == params[:id]
        redirect_to action: :me
      end
    end
  end

  def publishers_for(user)
    publishers = []
    user_publisher = user
    user_publisher.id = user.rid

    publishers << user_publisher
    publishers + user.institutions
  end

end
