module LearningObjectsHelper

  def display_object_type(learning_object)
    case learning_object.default_attachment.try(:mime_type)
      when /audio\/*/i then
        audio_tag(learning_object.cache_link, controls: true)
      when /video\/mp4/i then
        video_tag(learning_object.cache_link.to_s, autobuffer: true, poster: learning_object_thumbnail(learning_object))
      when /application\/(x-)?pdf/i then
        "<iframe src=\"/pdfjs/web/viewer.html?file=#{learning_object.retrieve_link }\" style=\"border: 0 \" width=\"125%\" height=\"280\" frameborder=\"0\" scrolling=\"no\"></iframe>".html_safe
      else
        image_tag learning_object_thumbnail(learning_object, 'large'), alt: learning_object_title(learning_object), class: 'thumbnail'
    end
  end

  def show_categories(categories = [])
    categories.to_s
  end

  def learning_object_thumbnail(learning_object, size = "")
    thumbnail = learning_object.default_thumbnail
    return thumbnail unless thumbnail.blank?

    unless learning_object.object_type.blank?
      case learning_object.object_type.name
        when 'Vídeo' then
          return 'video.png'
        when 'Imagem' then
          return 'image.png'
        when 'Hipertexto' then
          return 'text.png'
        when 'Animação/simulação' then
          return 'animation.png'
        when 'Software Educacional' then
          return 'software.png'
        when 'Áudio' then
          return 'audio.png'
        when 'Experimento prático' then
          return 'simulator.png'
      end
    end

    (size == 'large') ? 'learning-object-preview-large.png' : 'learning-object-preview.png'
  end

  def learning_object_title(learning_object)
    learning_object.name
  end

  def render_learning_object(orientation, learning_object)
    case (orientation)
      when 'vertical' then
        render 'learning_objects/learning_object_vertical', learning_object: learning_object
      when 'horizontal' then
        render 'learning_objects/learning_object_horizontal', learning_object: learning_object
      else
        render 'learning_objects/learning_object_horizontal', learning_object: learning_object
    end
  end

  def display_download_button(learning_object)
    return external_website_btn(learning_object) if learning_object.has_url_reference?
    download_btn learning_object
  end

  def social_share(learning_object)
    set_meta_tags og: {
        title: learning_object.name,
        type: 'website',
        description: learning_object.description,
        image: learning_object.default_thumbnail
    }

    set_meta_tags fb: {
        app_id: '745857965514514'
    }
  end

  def external_website_btn(learning_object)
    highlighted_btn learning_object.url_reference, 'Acessar website', 'fa-external-link'
  end

  def download_btn(learning_object)
    highlighted_btn download_learning_object_path(learning_object), 'Download', 'fa-download'
  end

  def highlighted_btn(url, _label = nil, _class = nil)
    link_to url, class: 'download btn btn-success', target: "_blank" do
      "<i class='fa #{_class}'></i> #{_label}".html_safe
    end
  end
end
