class ThumbnailGenerateWorker
  include Sidekiq::Worker

  def perform(attachment_id, media_path = nil, force = false)
    @attachment = ::LearningObject::Attachment.find(attachment_id)
    return false if @attachment.nil? || (!@attachment.thumbnail.blank? && !force)

    # object from dspace
    if media_path.nil?
      media = bitstream_download(@attachment.id_dspace)
      create_thumbnail(media)
      File.unlink(media) if File.exist?(media.path)
    # new object
    else
      create_thumbnail(create_media(media_path))
    end
  end

  private

  def create_media(path)
    return ::Screencap::Fetcher.new(path) if path =~ URI::regexp
    File.open path
  end

  def create_thumbnail(media)
    thumbnail = thumbnail_service.create_thumbnail(media)
    return false if thumbnail.blank?

    @attachment.update(thumbnail: thumbnail)
    File.unlink(thumbnail) if File.exist?(thumbnail.path)
  end

  def bitstream_download(id)
    client = DspaceService.create_client
    client.bitstreams.retrieve(id: id).open
  end

  def thumbnail_service
    @@thumbnailService ||= ThumbnailService.new(generators)
  end

  def generators
    [
      Thumbnail::Strategies::VideoThumbnailGenerator.new,
      Thumbnail::Strategies::ImageThumbnailGenerator.new,
      Thumbnail::Strategies::PdfThumbnailGenerator.new,
      Thumbnail::Strategies::UrlThumbnailGenerator.new
    ]
  end
end
